@@ -29,7 +29,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '2.12';
+our $VERSION = '2.13';
 
 sub new
 {
@@ -593,9 +593,15 @@ The following method returns the hash to all subscription details:
 
 =item $sms->getSubscriptions()
 
-0 means: not logged in
-
-1 means: logged in
+Returns an array with the subscription details:
+* each array contains a hash with "type", "name" and "items".
+* "type" is either "Tarif" or "Paket"
+* "name" is the name of the subscription
+* "items" contains an array with all items contained in the subscription.
+* each item-array contains a hash with "unit", "used" and "remaining"
+* "used" is the amount of already used units during the current accounting period
+* "remaining" is the amount of already remaining units during the current accounting period
+* "unit" contains the unit of "used" and "remaining"
 
 =back
 
@@ -667,6 +673,10 @@ Added "Changes"
 
 Corrected typo in description
 
+=item 2.13
+
+Improved documentation for getSubscriptions().
+
 =back
 
 =head1 AUTHOR
